# M🌚ri Message Linter

## Мощный, либеральный, классный - Проверит сообщения, скажет, что не так 💖


### Introduction
 - [О проекте](#about)
 - [Основные идеи и применение](#general-description)

### Quick start
 - Установка
 - Проверка сообщения
 - Конфигурация и настройка линтера
 - Проверка сообщений из файлов
 - Конфигурация и настройка линтера через командную строку

### General API Documentation

  * UseCases
    - ValidateLengthCase
    - ValidateHeartsIncludeCase
    - ValidateRequiredKeywordsCase
  * Linter Interfaces
    - MoriLinter
    - MoriFileLinter


<br>
<br>


<a name="about"></a>
<br>
<br>
### О проекте
M🌚ri Message Linter разработан в связи с несколькими прецедентами по количеству слов, 
а также общему содержанию в пожеланиях Доброго утра и Спокойной ночки. Чтобы избежать
в будущем подобных инцидентов, было проведено исследование по анализу всех ранее
написанных пожеланий утречка и ночки, выведены основные показатели KPI и метрики,
влияющие на положительный результат в настроении и эмоциональном фоне МикроМаши.


<a name="general-description"></a>
### Основные идеи и применение

Основная идея проекта заключается в автоматизации и оптимизации проверки сообщений
на соответствие стандартам, полученных в результате исследований и анализа информации,
собранной из сообщений за прошедшее время и периоды.
Такой подход к контролю качества сообщений позволит предупредить и исключить некоторые
возможные неприятные и непредвиденные ситуации.